Module external_command

Module external_command 

Re-exports

pub use crate::lint::Fix;

Structs

BuiltinAlternative
Metadata about a builtin alternative to an external command

Functions

detect_external_commands
Detect external commands with builtin alternatives
extract_external_args
Extract external command arguments as strings

Type Aliases

FixBuilder
Type alias for a function that builds a fix for a specific external command