pub type FixBuilder = fn(cmd_text: &str, alternative: &BuiltinAlternative, args: &[ExternalArgument], expr_span: Span, context: &LintContext<'_>) -> Fix;Expand description
Type alias for a function that builds a fix for a specific external command
pub type FixBuilder = fn(cmd_text: &str, alternative: &BuiltinAlternative, args: &[ExternalArgument], expr_span: Span, context: &LintContext<'_>) -> Fix;Type alias for a function that builds a fix for a specific external command