Re-exports
pub use crate::lint::Fix;
Structs
- Builtin
Alternative - Metadata about a builtin alternative to an external command
Functions
- detect_
external_ commands - Detect external commands with builtin alternatives
- extract_
external_ args - Extract external command arguments as strings
Type Aliases
- FixBuilder
- Type alias for a function that builds a fix for a specific external command