Shared utilities for rules that detect external commands with builtin alternatives
Re-exports
pub use crate::lint::Fix;
Structs
- Builtin
Alternative - Metadata about a builtin alternative to an external command
- External
Command Visitor - Generic AST visitor for detecting external commands with builtin alternatives
Type Aliases
- FixBuilder
- Type alias for a function that builds a fix for a specific external command