Module external_command

Module external_command 

Shared utilities for rules that detect external commands with builtin alternatives

Re-exports

pub use crate::lint::Fix;

Structs

BuiltinAlternative
Metadata about a builtin alternative to an external command
ExternalCommandVisitor
Generic AST visitor for detecting external commands with builtin alternatives

Type Aliases

FixBuilder
Type alias for a function that builds a fix for a specific external command